==> humhub-1.17.4.zip: humhub-1.17.4/protected/humhub/modules/space/messages/nl/base.php <==
<?php
return [
  '<b>This space is still empty!</b>' => '<b>Deze ruimte is nog leeg!</b>',
  '<b>This space is still empty!</b><br>Start by posting something here...' => '<b>Deze ruimte is nog leeg!</b><br>Begin met het schrijven van een bericht...',
  '<b>You are not member of this space and there is no public content, yet!</b>' => '<b>U bent geen lid van deze ruimte en er is nog geen openbare inhoud.</b>',
  '<strong>About</strong> the Space' => '<strong>Over</strong> deze ruimte',
  '<strong>About</strong> your membership' => '<strong>Over</strong> uw lidmaatschap',
  '<strong>Confirm</strong> image deletion' => '<strong>Bevestig</strong> het verwijderen van de afbeelding',
  '<strong>Invite</strong> members' => '<strong>Leden</strong> uitnodigen',
  '<strong>Leave</strong> Space' => '<strong>Laat een spatie achter</strong>',
  '<strong>New</strong> member request' => '<strong>Nieuw</strong> lidmaatschapsverzoek',
  '<strong>New</strong> spaces' => '<strong>Nieuwe</strong> ruimtes',
  '<strong>Request</strong> Membership' => '<strong>Vraag</strong> ruimte-lidmaatschap aan',
  '<strong>Space</strong> followers' => '<strong>Ruimte</strong> volgers',
  '<strong>Space</strong> members' => '<strong>Ruimte</strong> leden',
  '<strong>Space</strong> menu' => '<strong>Ruimte</strong> menu',
  '<strong>Space</strong> tags' => '<strong>Ruimte</strong>-labels',
  '<strong>Spaces</strong>' => '<strong>Ruimtes</strong>',
  'About' => 'Over',
  'Accept' => 'Aanvaarden',
  'Accept Invite' => 'Uitnodiging accepteren',
  'Access to this Space is restricted. Please introduce yourself to become a member.' => 'De toegang tot deze ruimte is beperkt. Stel uzelf even voor om lid te worden.',
  'Add as Default Space for new users' => 'Toevoegen als standaardruimte voor nieuwe gebruikers',
  'Add users without invitation' => 'Voeg gebruikers zonder uitnodiging toe',
  'Admin' => 'Beheerder',
  'Administrator:' => 'Beheerder:',
  'Administrators' => 'Beheerders',
  'Advanced Spaces Search' => 'Geavanceerd zoeken in ruimtes',
  'Any' => 'Elke',
  'Archived' => 'Gearchiveerd',
  'As owner you cannot revoke your membership!' => 'Als eigenaar kunt u uw lidmaatschap niet intrekken!',
  'Blocked users' => 'Geblokkeerde gebruikers',
  'By Name' => 'Bij naam',
  'Cancel' => 'Annuleren',
  'Change visibility' => 'Zichtbaarheid wijzigen',
  'Close' => 'Sluiten',
  'Color' => 'Kleur',
  'Could not request membership!' => 'Kon lidmaatschap niet aanvragen!',
  'Create new link' => 'Nieuwe link maken',
  'Created At' => 'Gemaakt op',
  'Created By' => 'Gemaakt door',
  'Decline' => 'Afwijzen',
  'Decline Invite' => 'Uitnodiging afwijzen',
  'Default' => 'Standaard',
  'Default Stream Sort' => 'Standaard berichtensortering',
  'Default content visibility' => 'Standaard zichtbaarheid inhoud',
  'Delete' => 'Verwijder',
  'Description' => 'Beschrijving',
  'Do you really want to delete your profile image?' => 'Wilt u  echt uw profielafbeelding verwijderen?',
  'Do you really want to delete your title image?' => 'Weet u zeker dat u uw titelafbeelding wilt verwijderen?',
  'Done' => 'Klaar',
  'Email addresses' => 'E-mailadres',
  'Everyone can enter' => 'Iedereen kan lid worden',
  'Find Spaces by their description or by their tags' => 'zoek Ruimtes via de beschrijving of de labels',
  'Follow' => 'Volgen',
  'Followers' => 'Volgers',
  'Following' => 'Volgend',
  'Guests' => 'Gasten',
  'Hide About Page' => 'Verberg Over pagina',
  'Hide Activity Sidebar Widget' => 'Activiteitszijbalk-widget verbergen',
  'Hide Followers' => 'Verberg volgers',
  'Hide Members' => 'Verberg leden',
  'Homepage' => 'Startpagina',
  'Homepage (Non-members)' => 'Startpagina (niet-leden)',
  'I want to become a member because...' => 'Ik wil lid worden omdat...',
  'Incorrect name, try again.' => 'Onjuiste naam, probeer het opnieuw.',
  'Invite' => 'Uitnodigen',
  'Invite and request' => 'Uitnodigen en aanvragen',
  'Invite by email' => 'Uitnodigen per e-mail',
  'Invite by link' => 'Uitnodigen per link',
  'Invite link' => 'Uitnodigingslink',
  'Invites' => 'Uitnodigingen',
  'Join' => 'Doe mee',
  'Join Policy' => 'Gedragslijn om lid te worden',
  'Last Visit' => 'Laatste bezoek',
  'Leave' => 'Verlaat',
  'Login' => 'Log in',
  'Max. 100 characters.' => 'Maximaal 100 tekens',
  'Member' => 'Lid',
  'Member since' => 'Lid sinds',
  'Members' => 'Leden',
  'Moderator' => 'Moderator',
  'Moderator:' => 'Moderator:',
  'Moderators' => 'Moderators',
  'My Space List' => 'Mijn Ruimte Lijst',
  'My space summary' => 'Mijn ruimte overzicht',
  'Name' => 'Naam',
  'Name / Sort order' => 'Naam / Sorteervolgorde',
  'Neither..nor' => 'Noch ... noch',
  'New user by e-mail (comma separated)' => 'Nieuwe gebruikers uitnodigen per e-mail (gescheiden door komma)',
  'New user?' => 'Nieuwe gebruiker?',
  'Newest first' => 'Nieuwste eerst',
  'No results found!' => 'Geen resultaten gevonden!',
  'No spaces found.' => 'Geen ruimtes gevonden',
  'Oldest first' => 'Oudste eerst',
  'Only by invite' => 'Alleen door uitnodiging',
  'Originator User ID' => 'Oprichter gebruiker ID',
  'Owner' => 'Eigenaar',
  'Owner:' => 'Eigenaar:',
  'Pending' => 'In afwachting',
  'Pick users' => 'Selecteer gebruikers',
  'Please note that any links you have previously created will become invalid as soon as you create a new one. Would you like to proceed?' => 'Houd er rekening mee dat links die u eerder hebt gemaakt, ongeldig worden zodra u een nieuwe maakt. Wilt u doorgaan?',
  'Posts' => 'Berichten',
  'Private' => 'Privé',
  'Private (Invisible)' => 'Privaat (Onzichtbaar)',
  'Public' => 'Publiek',
  'Public (Members & Guests)' => 'Publiek (Leden &amp; Gasten)',
  'Public (Members only)' => 'Publiek (Alleen leden)',
  'Public (Registered users only)' => 'Publiek (Alleen geregistreerde gebruikers)',
  'Request Message' => 'Verzoek bericht',
  'Role' => 'Rol',
  'Search...' => 'Zoeken...',
  'See all' => 'Toon alle',
  'Select all registered users' => 'Selecteer alle geregistreerde gebruikers',
  'Send' => 'Versturen',
  'Send the link via email' => 'Stuur de link per e-mail',
  'Settings' => 'Instellingen',
  'Settings could not be saved!' => 'De instellingen kunnen niet worden opgeslagen!',
  'Show all' => 'Alles weergeven',
  'Show as List' => 'Weergeven als lijst',
  'Shown on About Page.' => 'Weergegeven op de Over-pagina.',
  'Sorry, you are not allowed to leave this space!' => 'Sorry,  u kunt deze ruimte niet verlaten!',
  'Sorting' => 'Sortering',
  'Space' => 'Ruimte',
  'Space Name' => 'Naam van de ruimte',
  'Space Visibility' => 'Zichtbaarheid van de ruimte',
  'Space directory' => 'Ruimte overzicht',
  'Space is invisible!' => 'Ruimte is onzichtbaar!',
  'Spaces' => 'Ruimtes',
  'Status' => 'Status',
  'Stream' => 'Stream',
  'Stream Sort' => 'Berichtensortering',
  'Tags' => 'Labels',
  'The default homepage for members of this Space' => 'De standaard startpagina voor leden van deze Ruimte',
  'The default homepage for non-members and guests visiting this Space' => 'De standaard startpagina voor niet-leden en gasten die deze Ruimte bezoeken',
  'The secure link has been copied in your clipboard!' => 'De beveiligde link is naar het klembord gekopieerd!',
  'There is no pending invite!' => 'Er zijn geen uitnodigingen in behandeling.',
  'This action is only available for workspace members!' => 'Deze actie is enkel beschikbaar voor leden van de ruimte!',
  'This user is already a member of this space.' => 'De gebruiker is al lid van deze ruimte.',
  'This user is not a member of this space.' => 'De gebruiker is niet een lid van deze ruimte.',
  'To invite users to this space, please type their names below to find and pick them.' => 'Om gebruikers uit te nodigen, vul je hun naam hieronder in om ze te zoeken en selecteren.',
  'Try other keywords or remove filters.' => 'Probeer andere zoekwoorden of verwijder filters.',
  'Updated At' => 'Aangepast op',
  'Updated By' => 'Bijgewerkt door',
  'Updated by' => 'Aangepast door',
  'User \'{username}\' is already a member of this space!' => 'Gebruiker \'{username}\' is al lid van deze ruimte!',
  'User invitations have been added to the queue' => 'Gebruikersuitnodigingen zijn aan de wachtrij toegevoegd.',
  'User memberships have been added to the queue' => 'Gebruikerslidmaatschappen zijn toegevoegd aan de wachtrij.',
  'User not found!' => 'Gebruiker niet gevonden!',
  'Users' => 'Gebruikers',
  'Users has been invited.' => 'De gebruikers zijn uitgenodigd.',
  'Visibility' => 'Zichtbaarheid',
  'Visible for all (members and guests)' => 'Zichtbaar voor iedereen (leden en gasten)',
  'Warning: If you change the visibility settings of a Space from public to private, all content within that Space, including posts, comments, attachments etc. will also be set to private. This means that non-members will no longer be able to see, access, or interact with any of the content within that Space.' => 'Waarschuwing: als u de zichtbaarheidsinstellingen van een ruimte wijzigt van openbaar naar privé, wordt alle inhoud in die ruimte, inclusief berichten, opmerkingen, bijlagen enz., ook ingesteld op privé. Dit betekent dat niet-leden de inhoud van die ruimte niet langer kunnen zien, openen of gebruiken.',
  'Would you like to end your membership in Space {spaceName}?' => 'Wilt u uw lidmaatschap in de ruimte {spaceName} beëindigen?',
  'Would you like to unfollow Space {spaceName}?' => 'Wilt  u ruimte {spaceName} niet meer volgen?',
  'Would you like to unfollow {userName}?' => 'Wilt u {userName} niet meer volgen?',
  'Would you like to withdraw your request to join Space {spaceName}?' => 'Wilt u uw verzoek om lid te worden van ruimte {spaceName} intrekken?',
  'You are not allowed to join this space!' => 'U mag geen lid worden van deze ruimte!',
  'You can also invite external users by email, which are not registered now. Just add their e-mail addresses separated by comma.' => 'U kunt ook nieuwe gebruikers per e-mail uitnodigen. Voeg gewoon hun e-mailadressen toe, gescheiden door komma\'s.',
  'You can invite external users who are currently not registered via link. All you need to do is share this secure link with them.' => 'U kunt ook nieuwe gebruikers uitnodigen door deze beveiligde link met hen te delen.',
  'You cannot create private visible spaces!' => 'U kunt geen privaat zichtbare ruimtes aanmaken!',
  'You cannot create public visible spaces!' => 'U kunt geen publiek zichtbare ruimtes aanmaken!',
  'You need to login to view contents of this space!' => 'U moet zich aanmelden om de inhoud van deze ruimte te zien!',
  'Your Message' => 'Applicatie melding',
  'Your request was successfully submitted to the space administrators.' => 'Uw aanvraag is succesvol naar de ruimte-beheerder verstuurd.',
  '{count} members' => '{count} leden',
  '{email} is not valid!' => '{email} is niet geldig!',
];

==> humhub-1.18.0.zip: humhub-1.18.0/protected/humhub/modules/space/messages/nl/base.php <==
<?php
return [
  '<b>This space is still empty!</b>' => '<b>Deze ruimte is nog leeg!</b>',
  '<b>This space is still empty!</b><br>Start by posting something here...' => '<b>Deze ruimte is nog leeg!</b><br>Begin met het schrijven van een bericht...',
  '<b>You are not member of this space and there is no public content, yet!</b>' => '<b>U bent geen lid van deze ruimte en er is nog geen openbare inhoud.</b>',
  '<strong>About</strong> the Space' => '<strong>Over</strong> deze ruimte',
  '<strong>About</strong> your membership' => '<strong>Over</strong> uw lidmaatschap',
  '<strong>Confirm</strong> image deletion' => '<strong>Bevestig</strong> het verwijderen van de afbeelding',
  '<strong>Invite</strong> members' => '<strong>Leden</strong> uitnodigen',
  '<strong>Leave</strong> Space' => '<strong>Verlaat</strong> deze ruimte',
  '<strong>New</strong> member request' => '<strong>Nieuw</strong> lidmaatschapsverzoek',
  '<strong>New</strong> spaces' => '<strong>Nieuwe</strong> ruimtes',
  '<strong>Request</strong> Membership' => '<strong>Vraag</strong> ruimte-lidmaatschap aan',
  '<strong>Space</strong> followers' => '<strong>Ruimte</strong> volgers',
  '<strong>Space</strong> members' => '<strong>Ruimte</strong> leden',
  '<strong>Space</strong> menu' => '<strong>Ruimte</strong> menu',
  '<strong>Space</strong> tags' => '<strong>Ruimte</strong>-labels',
  '<strong>Spaces</strong>' => '<strong>Ruimtes</strong>',
  'About' => 'Over',
  'Accept' => 'Aanvaarden',
  'Accept Invite' => 'Uitnodiging accepteren',
  'Access to this Space is restricted. Please introduce yourself to become a member.' => 'De toegang tot deze ruimte is beperkt. Stel uzelf even voor om lid te worden.',
  'Add as Default Space for new users' => 'Toevoegen als standaardruimte voor nieuwe gebruikers',
  'Add users without invitation' => 'Voeg gebruikers zonder uitnodiging toe',
  'Admin' => 'Beheerder',
  'Administrator:' => 'Beheerder:',
  'Administrators' => 'Beheerders',
  'Advanced Spaces Search' => 'Geavanceerd zoeken in ruimtes',
  'Any' => 'Elke',
  'Archived' => 'Gearchiveerd',
  'As owner you cannot revoke your membership!' => 'Als eigenaar kunt u uw lidmaatschap niet intrekken!',
  'Blocked users' => 'Geblokkeerde gebruikers',
  'By Name' => 'Bij naam',
  'Cancel' => 'Annuleren',
  'Change visibility' => 'Zichtbaarheid wijzigen',
  'Color' => 'Kleur',
  'Could not request membership!' => 'Kon lidmaatschap niet aanvragen!',
  'Create new link' => 'Nieuwe link maken',
  'Created At' => 'Gemaakt op',
  'Created By' => 'Gemaakt door',
  'Decline' => 'Afwijzen',
  'Decline Invite' => 'Uitnodiging afwijzen',
  'Default' => 'Standaard',
  'Default Stream Sort' => 'Standaard berichtensortering',
  'Default content visibility' => 'Standaard zichtbaarheid inhoud',
  'Delete' => 'Verwijder',
  'Description' => 'Beschrijving',
  'Do you really want to delete your profile image?' => 'Wilt u  echt uw profielafbeelding verwijderen?',
  'Do you really want to delete your title image?' => 'Weet u zeker dat u uw titelafbeelding wilt verwijderen?',
  'Done' => 'Klaar',
  'Email addresses' => 'E-mailadres',
  'Everyone can enter' => 'Iedereen kan lid worden',
  'Find Spaces by their description or by their tags' => 'zoek Ruimtes via de beschrijving of de labels',
  'Follow' => 'Volgen',
  'Followers' => 'Volgers',
  'Following' => 'Volgend',
  'Guests' => 'Gasten',
  'Hide About Page' => 'Verberg Over pagina',
  'Hide Activity Sidebar Widget' => 'Activiteitszijbalk-widget verbergen',
  'Hide Followers' => 'Verberg volgers',
  'Hide Members' => 'Verberg leden',
  'Homepage' => 'Startpagina',
  'Homepage (Non-members)' => 'Startpagina (niet-leden)',
  'I want to become a member because...' => 'Ik wil lid worden omdat...',
  'Incorrect name, try again.' => 'Onjuiste naam, probeer het opnieuw.',
  'Invite' => 'Uitnodigen',
  'Invite and request' => 'Uitnodigen en aanvragen',
  'Invite by email' => 'Uitnodigen per e-mail',
  'Invite by link' => 'Uitnodigen per link',
  'Invite link' => 'Uitnodigingslink',
  'Invites' => 'Uitnodigingen',
  'Join' => 'Doe mee',
  'Join Policy' => 'Gedragslijn om lid te worden',
  'Last Visit' => 'Laatste bezoek',
  'Leave' => 'Verlaat',
  'Login' => 'Log in',
  'Max. 100 characters.' => 'Maximaal 100 tekens',
  'Member' => 'Lid',
  'Member since' => 'Lid sinds',
  'Members' => 'Leden',
  'Moderator' => 'Moderator',
  'Moderator:' => 'Moderator:',
  'Moderators' => 'Moderators',
  'My Space List' => 'Mijn Ruimte Lijst',
  'My space summary' => 'Mijn ruimte overzicht',
  'Name' => 'Naam',
  'Name / Sort order' => 'Naam / Sorteervolgorde',
  'Neither..nor' => 'Noch ... noch',
  'New user by e-mail (comma separated)' => 'Nieuwe gebruikers uitnodigen per e-mail (gescheiden door komma)',
  'New user?' => 'Nieuwe gebruiker?',
  'Newest first' => 'Nieuwste eerst',
  'No results found!' => 'Geen resultaten gevonden!',
  'No spaces found.' => 'Geen ruimtes gevonden',
  'Oldest first' => 'Oudste eerst',
  'Only by invite' => 'Alleen door uitnodiging',
  'Originator User ID' => 'Oprichter gebruiker ID',
  'Owner' => 'Eigenaar',
  'Owner:' => 'Eigenaar:',
  'Pending' => 'In afwachting',
  'Pick users' => 'Selecteer gebruikers',
  'Please note that any links you have previously created will become invalid as soon as you create a new one. Would you like to proceed?' => 'Houd er rekening mee dat links die u eerder hebt gemaakt, ongeldig worden zodra u een nieuwe maakt. Wilt u doorgaan?',
  'Posts' => 'Berichten',
  'Private' => 'Privé',
  'Private (Invisible)' => 'Privaat (Onzichtbaar)',
  'Public' => 'Publiek',
  'Public (Members & Guests)' => 'Publiek (Leden &amp; Gasten)',
  'Public (Members only)' => 'Publiek (Alleen leden)',
  'Public (Registered users only)' => 'Publiek (Alleen geregistreerde gebruikers)',
  'Request Message' => 'Verzoek bericht',
  'Role' => 'Rol',
  'Search...' => 'Zoeken...',
  'See all' => 'Toon alle',
  'Select all registered users' => 'Selecteer alle geregistreerde gebruikers',
  'Send' => 'Versturen',
  'Send the link via email' => 'Stuur de link per e-mail',
  'Settings' => 'Instellingen',
  'Settings could not be saved!' => 'De instellingen kunnen niet worden opgeslagen!',
  'Show all' => 'Alles weergeven',
  'Show as List' => 'Weergeven als lijst',
  'Shown on About Page.' => 'Weergegeven op de Over-pagina.',
  'Sorry, you are not allowed to leave this space!' => 'Sorry,  u kunt deze ruimte niet verlaten!',
  'Sorting' => 'Sortering',
  'Space' => 'Ruimte',
  'Space Name' => 'Naam van de ruimte',
  'Space Visibility' => 'Zichtbaarheid van de ruimte',
  'Space directory' => 'Ruimte overzicht',
  'Space is invisible!' => 'Ruimte is onzichtbaar!',
  'Spaces' => 'Ruimtes',
  'Status' => 'Status',
  'Stream' => 'Stream',
  'Stream Sort' => 'Berichtensortering',
  'Tags' => 'Labels',
  'The default homepage for members of this Space' => 'De standaard startpagina voor leden van deze Ruimte',
  'The default homepage for non-members and guests visiting this Space' => 'De standaard startpagina voor niet-leden en gasten die deze Ruimte bezoeken',
  'The secure link has been copied in your clipboard!' => 'De beveiligde link is naar het klembord gekopieerd!',
  'There is no pending invite!' => 'Er zijn geen uitnodigingen in behandeling.',
  'This action is only available for workspace members!' => 'Deze actie is enkel beschikbaar voor leden van de ruimte!',
  'This user is already a member of this space.' => 'De gebruiker is al lid van deze ruimte.',
  'This user is not a member of this space.' => 'De gebruiker is niet een lid van deze ruimte.',
  'To invite users to this space, please type their names below to find and pick them.' => 'Om gebruikers uit te nodigen, vul je hun naam hieronder in om ze te zoeken en selecteren.',
  'Try other keywords or remove filters.' => 'Probeer andere zoekwoorden of verwijder filters.',
  'Updated At' => 'Aangepast op',
  'Updated By' => 'Bijgewerkt door',
  'Updated by' => 'Aangepast door',
  'User \'{username}\' is already a member of this space!' => 'Gebruiker \'{username}\' is al lid van deze ruimte!',
  'User invitations have been added to the queue' => 'Gebruikersuitnodigingen zijn aan de wachtrij toegevoegd.',
  'User memberships have been added to the queue' => 'Gebruikerslidmaatschappen zijn toegevoegd aan de wachtrij.',
  'User not found!' => 'Gebruiker niet gevonden!',
  'Users' => 'Gebruikers',
  'Users has been invited.' => 'De gebruikers zijn uitgenodigd.',
  'Visibility' => 'Zichtbaarheid',
  'Visible for all (members and guests)' => 'Zichtbaar voor iedereen (leden en gasten)',
  'Warning: If you change the visibility settings of a Space from public to private, all content within that Space, including posts, comments, attachments etc. will also be set to private. This means that non-members will no longer be able to see, access, or interact with any of the content within that Space.' => 'Waarschuwing: als u de zichtbaarheidsinstellingen van een ruimte wijzigt van openbaar naar privé, wordt alle inhoud in die ruimte, inclusief berichten, opmerkingen, bijlagen enz., ook ingesteld op privé. Dit betekent dat niet-leden de inhoud van die ruimte niet langer kunnen zien, openen of gebruiken.',
  'Would you like to end your membership in Space {spaceName}?' => 'Wilt u uw lidmaatschap in de ruimte {spaceName} beëindigen?',
  'Would you like to unfollow Space {spaceName}?' => 'Wilt  u ruimte {spaceName} niet meer volgen?',
  'Would you like to unfollow {userName}?' => 'Wilt u {userName} niet meer volgen?',
  'Would you like to withdraw your request to join Space {spaceName}?' => 'Wilt u uw verzoek om lid te worden van ruimte {spaceName} intrekken?',
  'You are not allowed to join this space!' => 'U mag geen lid worden van deze ruimte!',
  'You can also invite external users by email, which are not registered now. Just add their e-mail addresses separated by comma.' => 'U kunt ook nieuwe gebruikers per e-mail uitnodigen. Voeg gewoon hun e-mailadressen toe, gescheiden door komma\'s.',
  'You can invite external users who are currently not registered via link. All you need to do is share this secure link with them.' => 'U kunt ook nieuwe gebruikers uitnodigen door deze beveiligde link met hen te delen.',
  'You cannot create private visible spaces!' => 'U kunt geen privaat zichtbare ruimtes aanmaken!',
  'You cannot create public visible spaces!' => 'U kunt geen publiek zichtbare ruimtes aanmaken!',
  'You need to login to view contents of this space!' => 'U moet zich aanmelden om de inhoud van deze ruimte te zien!',
  'Your Message' => 'Applicatie melding',
  'Your request was successfully submitted to the space administrators.' => 'Uw aanvraag is succesvol naar de ruimte-beheerder verstuurd.',
  '{count} members' => '{count} leden',
  '{email} is not valid!' => '{email} is niet geldig!',
];
